#ifndef _MIMETYPE_H
#define _MIMETYPE_H

typedef struct type_mimename {
    char *name;

    struct type_mimename *next;
} t_mimename;

typedef struct type_extension {
    char *name;
    struct type_mimename *mimename;

    struct type_extension *next;
} t_extension;

typedef struct type_mime {
	t_mimename  *mimename;
    t_extension *extension;
} t_mimetype;

int  read_mimetypes(char *configfile, t_mimetype **mime);
char *get_mimetype(char *filename, t_mimetype *mime);

#endif
